﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ROGOZ.Pages
{
    /// <summary>
    /// Логика взаимодействия для TaskList.xaml
    /// </summary>
    public partial class TaskList : Page
    {
        public TaskList()
        {
            InitializeComponent();

            CmbStatusSort.ItemsSource = Status.FillStatus();
            CmbExecutorSort.ItemsSource = user1Entities.GetContext().Executor.ToList();
            

            DGTasks.ItemsSource = user1Entities.GetContext().Task.ToList();
        }

        private void BtnAdd_Click(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new AddEditPage(null));
        }

        private void BtnEdit_Click(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new AddEditPage((sender as Button).DataContext as Task));
        }

        private void BtnDelTask_Click(object sender, RoutedEventArgs e)
        {
            var taskIsForRemoving = DGTasks.SelectedItems.Cast<Task>().ToList();
            if (MessageBox.Show($"Вы точно хотите удалить {taskIsForRemoving.Count()} задач?", 
                "Внимание",MessageBoxButton.YesNo, MessageBoxImage.Question)==MessageBoxResult.Yes)
            {
                try
                {
                    user1Entities.GetContext().Task.RemoveRange(taskIsForRemoving);
                    user1Entities.GetContext().SaveChanges();
                    MessageBox.Show("Данные удалены");
                    DGTasks.ItemsSource = user1Entities.GetContext().Task.ToList();
                }
                catch (Exception ex) {MessageBox.Show(ex.Message.ToString());}
            }
        }


        private void UpdateTasks()
        {
            var tasks = user1Entities.GetContext().Task.ToList();

            //сортировка по статусу
            if (CmbStatusSort.SelectedIndex == 0)
                tasks = tasks.OrderBy(p => p.Status).ToList();
            else
                tasks = tasks.OrderByDescending(p => p.Status).ToList();
            //if (CmbStatusSort.SelectedIndex==0)
            //    tasks = tasks.OrderBy(p=> p.Status).ToList();
            //else
            //tasks = tasks.Where(p=> p.Status.ToLower().Contains(CmbStatusSort.Text.ToLower())).ToList();

            //сортировка по исполнителю
            if (CmbExecutorSort.SelectedIndex == 0)
                tasks = tasks.OrderBy(p => p.ExecutorID).ToList();
            else
                tasks = tasks.OrderByDescending(p => p.ExecutorID).ToList();

            //сортировка по поиску
            tasks = tasks.Where(p => p.Title.ToLower().Contains(TBoxSearch.Text.ToLower())).ToList();

            DGTasks.ItemsSource = tasks;
        }

        private void CmbStatusSort_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            UpdateTasks();
        }

        private void TBoxSearch_TextChanged(object sender, TextChangedEventArgs e)
        {
            UpdateTasks();
        }

        private void ClearFilters_Click(object sender, RoutedEventArgs e)
        {
            CmbExecutorSort.SelectedIndex = 0;
            CmbStatusSort.SelectedIndex = 0;
            TBoxSearch.Clear();
        }
    }
}
